# flake8: noqa
from .core import extract_predictions
from .dataclass import OCRResult
